package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.ClewVideo;

/**
 * 线索视频Mapper接口
 *
 * @author ruoyi
 * @date 2023-11-06
 */
public interface ClewVideoMapper
{
    /**
     * 查询线索视频
     *
     * @param id 线索视频主键
     * @return 线索视频
     */
    public ClewVideo selectClewVideoById(Long id);

    /**
     * 查询线索视频列表
     *
     * @param clewVideo 线索视频
     * @return 线索视频集合
     */
    public List<ClewVideo> selectClewVideoList(ClewVideo clewVideo);

    /**
     * 新增线索视频
     *
     * @param clewVideo 线索视频
     * @return 结果
     */
    public int insertClewVideo(ClewVideo clewVideo);

    /**
     * 修改线索视频
     *
     * @param clewVideo 线索视频
     * @return 结果
     */
    public int updateClewVideo(ClewVideo clewVideo);

    /**
     * 删除线索视频
     *
     * @param id 线索视频主键
     * @return 结果
     */
    public int deleteClewVideoById(Long id);

    /**
     * 批量删除线索视频
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteClewVideoByIds(String[] ids);
}
